==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkSynchronizedRenderers.java <==
// java wrapper for vtkSynchronizedRenderers object
//

package vtk;
import vtk.*;

public class vtkSynchronizedRenderers extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRenderer_2(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_2(id0); }

  private native long GetRenderer_3();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_3();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetParallelController_4(vtkMultiProcessController id0);
  public void SetParallelController(vtkMultiProcessController id0)
    { SetParallelController_4(id0); }

  private native long GetParallelController_5();
  public vtkMultiProcessController GetParallelController() {
    long temp = GetParallelController_5();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetParallelRendering_6(boolean id0);
  public void SetParallelRendering(boolean id0)
    { SetParallelRendering_6(id0); }

  private native boolean GetParallelRendering_7();
  public boolean GetParallelRendering()
    { return GetParallelRendering_7(); }

  private native void ParallelRenderingOn_8();
  public void ParallelRenderingOn()
    { ParallelRenderingOn_8(); }

  private native void ParallelRenderingOff_9();
  public void ParallelRenderingOff()
    { ParallelRenderingOff_9(); }

  private native void SetImageReductionFactor_10(int id0);
  public void SetImageReductionFactor(int id0)
    { SetImageReductionFactor_10(id0); }

  private native int GetImageReductionFactorMinValue_11();
  public int GetImageReductionFactorMinValue()
    { return GetImageReductionFactorMinValue_11(); }

  private native int GetImageReductionFactorMaxValue_12();
  public int GetImageReductionFactorMaxValue()
    { return GetImageReductionFactorMaxValue_12(); }

  private native int GetImageReductionFactor_13();
  public int GetImageReductionFactor()
    { return GetImageReductionFactor_13(); }

  private native void SetWriteBackImages_14(boolean id0);
  public void SetWriteBackImages(boolean id0)
    { SetWriteBackImages_14(id0); }

  private native boolean GetWriteBackImages_15();
  public boolean GetWriteBackImages()
    { return GetWriteBackImages_15(); }

  private native void WriteBackImagesOn_16();
  public void WriteBackImagesOn()
    { WriteBackImagesOn_16(); }

  private native void WriteBackImagesOff_17();
  public void WriteBackImagesOff()
    { WriteBackImagesOff_17(); }

  private native void SetUseFXAA_18(boolean id0);
  public void SetUseFXAA(boolean id0)
    { SetUseFXAA_18(id0); }

  private native boolean GetUseFXAA_19();
  public boolean GetUseFXAA()
    { return GetUseFXAA_19(); }

  private native void UseFXAAOn_20();
  public void UseFXAAOn()
    { UseFXAAOn_20(); }

  private native void UseFXAAOff_21();
  public void UseFXAAOff()
    { UseFXAAOff_21(); }

  private native long GetFXAAOptions_22();
  public vtkFXAAOptions GetFXAAOptions() {
    long temp = GetFXAAOptions_22();

    if (temp == 0) return null;
    return (vtkFXAAOptions)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFXAAOptions_23(vtkFXAAOptions id0);
  public void SetFXAAOptions(vtkFXAAOptions id0)
    { SetFXAAOptions_23(id0); }

  private native void SetRootProcessId_24(int id0);
  public void SetRootProcessId(int id0)
    { SetRootProcessId_24(id0); }

  private native int GetRootProcessId_25();
  public int GetRootProcessId()
    { return GetRootProcessId_25(); }

  private native void CollectiveExpandForVisiblePropBounds_26(double id0[]);
  public void CollectiveExpandForVisiblePropBounds(double id0[])
    { CollectiveExpandForVisiblePropBounds_26(id0); }

  private native void SetCaptureDelegate_27(vtkSynchronizedRenderers id0);
  public void SetCaptureDelegate(vtkSynchronizedRenderers id0)
    { SetCaptureDelegate_27(id0); }

  private native long GetCaptureDelegate_28();
  public vtkSynchronizedRenderers GetCaptureDelegate() {
    long temp = GetCaptureDelegate_28();

    if (temp == 0) return null;
    return (vtkSynchronizedRenderers)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAutomaticEventHandling_29(boolean id0);
  public void SetAutomaticEventHandling(boolean id0)
    { SetAutomaticEventHandling_29(id0); }

  private native boolean GetAutomaticEventHandling_30();
  public boolean GetAutomaticEventHandling()
    { return GetAutomaticEventHandling_30(); }

  private native void AutomaticEventHandlingOn_31();
  public void AutomaticEventHandlingOn()
    { AutomaticEventHandlingOn_31(); }

  private native void AutomaticEventHandlingOff_32();
  public void AutomaticEventHandlingOff()
    { AutomaticEventHandlingOff_32(); }

  public vtkSynchronizedRenderers() { super(); }

  public vtkSynchronizedRenderers(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkSynchronizedRenderers.java <==
// java wrapper for vtkSynchronizedRenderers object
//

package vtk;
import vtk.*;

public class vtkSynchronizedRenderers extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetRenderer_2(vtkRenderer id0);
  public void SetRenderer(vtkRenderer id0)
    { SetRenderer_2(id0); }

  private native long GetRenderer_3();
  public vtkRenderer GetRenderer() {
    long temp = GetRenderer_3();

    if (temp == 0) return null;
    return (vtkRenderer)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetParallelController_4(vtkMultiProcessController id0);
  public void SetParallelController(vtkMultiProcessController id0)
    { SetParallelController_4(id0); }

  private native long GetParallelController_5();
  public vtkMultiProcessController GetParallelController() {
    long temp = GetParallelController_5();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetParallelRendering_6(boolean id0);
  public void SetParallelRendering(boolean id0)
    { SetParallelRendering_6(id0); }

  private native boolean GetParallelRendering_7();
  public boolean GetParallelRendering()
    { return GetParallelRendering_7(); }

  private native void ParallelRenderingOn_8();
  public void ParallelRenderingOn()
    { ParallelRenderingOn_8(); }

  private native void ParallelRenderingOff_9();
  public void ParallelRenderingOff()
    { ParallelRenderingOff_9(); }

  private native void SetImageReductionFactor_10(int id0);
  public void SetImageReductionFactor(int id0)
    { SetImageReductionFactor_10(id0); }

  private native int GetImageReductionFactorMinValue_11();
  public int GetImageReductionFactorMinValue()
    { return GetImageReductionFactorMinValue_11(); }

  private native int GetImageReductionFactorMaxValue_12();
  public int GetImageReductionFactorMaxValue()
    { return GetImageReductionFactorMaxValue_12(); }

  private native int GetImageReductionFactor_13();
  public int GetImageReductionFactor()
    { return GetImageReductionFactor_13(); }

  private native void SetWriteBackImages_14(boolean id0);
  public void SetWriteBackImages(boolean id0)
    { SetWriteBackImages_14(id0); }

  private native boolean GetWriteBackImages_15();
  public boolean GetWriteBackImages()
    { return GetWriteBackImages_15(); }

  private native void WriteBackImagesOn_16();
  public void WriteBackImagesOn()
    { WriteBackImagesOn_16(); }

  private native void WriteBackImagesOff_17();
  public void WriteBackImagesOff()
    { WriteBackImagesOff_17(); }

  private native void SetRootProcessId_18(int id0);
  public void SetRootProcessId(int id0)
    { SetRootProcessId_18(id0); }

  private native int GetRootProcessId_19();
  public int GetRootProcessId()
    { return GetRootProcessId_19(); }

  private native void CollectiveExpandForVisiblePropBounds_20(double id0[]);
  public void CollectiveExpandForVisiblePropBounds(double id0[])
    { CollectiveExpandForVisiblePropBounds_20(id0); }

  private native void SetCaptureDelegate_21(vtkSynchronizedRenderers id0);
  public void SetCaptureDelegate(vtkSynchronizedRenderers id0)
    { SetCaptureDelegate_21(id0); }

  private native long GetCaptureDelegate_22();
  public vtkSynchronizedRenderers GetCaptureDelegate() {
    long temp = GetCaptureDelegate_22();

    if (temp == 0) return null;
    return (vtkSynchronizedRenderers)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetAutomaticEventHandling_23(boolean id0);
  public void SetAutomaticEventHandling(boolean id0)
    { SetAutomaticEventHandling_23(id0); }

  private native boolean GetAutomaticEventHandling_24();
  public boolean GetAutomaticEventHandling()
    { return GetAutomaticEventHandling_24(); }

  private native void AutomaticEventHandlingOn_25();
  public void AutomaticEventHandlingOn()
    { AutomaticEventHandlingOn_25(); }

  private native void AutomaticEventHandlingOff_26();
  public void AutomaticEventHandlingOff()
    { AutomaticEventHandlingOff_26(); }

  public vtkSynchronizedRenderers() { super(); }

  public vtkSynchronizedRenderers(long id) { super(id); }
  public native long   VTKInit();

}
